summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorwm4 <wm4@nowhere>2015-11-07 17:49:14 +0100
committerwm4 <wm4@nowhere>2015-11-07 17:49:14 +0100
commit46cee66563eafee80fd7983916fee4388c54d8ab (patch)
treeba953e6e0fc280df2cb84420bf4a811c4203abdf
parent0062c98dfffcb667b9d0cd739abc107e0145df63 (diff)
downloadmpv-46cee66563eafee80fd7983916fee4388c54d8ab.tar.bz2
mpv-46cee66563eafee80fd7983916fee4388c54d8ab.tar.xz
vo_opengl: rename fancy-downscaling to correct-downscaling
The old name was stupid. Very stupid.
-rw-r--r--DOCS/man/vo.rst4
-rw-r--r--video/out/opengl/video.c17
-rw-r--r--video/out/opengl/video.h2
3 files changed, 11 insertions, 12 deletions
diff --git a/DOCS/man/vo.rst b/DOCS/man/vo.rst
index a02c827d0d..2f8bcb3661 100644
--- a/DOCS/man/vo.rst
+++ b/DOCS/man/vo.rst
@@ -541,7 +541,7 @@ Available video output drivers are:
Scale in linear light. It should only be used with a ``fbo-format``
that has at least 16 bit precision.
- ``fancy-downscaling``
+ ``correct-downscaling``
When using convolution based filters, extend the filter size
when downscaling. Trades quality for reduced downscaling performance.
@@ -949,7 +949,7 @@ Available video output drivers are:
This is equivalent to::
- --vo=opengl:scale=spline36:cscale=spline36:dscale=mitchell:dither-depth=auto:fancy-downscaling:sigmoid-upscaling:pbo:deband
+ --vo=opengl:scale=spline36:cscale=spline36:dscale=mitchell:dither-depth=auto:correct-downscaling:sigmoid-upscaling:pbo:deband
Note that some cheaper LCDs do dithering that gravely interferes with
``opengl``'s dithering. Disabling dithering with ``dither-depth=no`` helps.
diff --git a/video/out/opengl/video.h b/video/out/opengl/video.h
index df55ede27d..c7c567d50c 100644
--- a/video/out/opengl/video.h
+++ b/video/out/opengl/video.h
@@ -75,7 +75,7 @@ struct gl_video_opts {
int target_prim;
int target_trc;
int linear_scaling;
- int fancy_downscaling;
+ int correct_downscaling;
int sigmoid_upscaling;
float sigmoid_center;
float sigmoid_slope;
diff --git a/video/out/opengl/video.c b/video/out/opengl/video.c
index 55f0e70476..2c3a22d1ca 100644
--- a/video/out/opengl/video.c
+++ b/video/out/opengl/video.c
@@ -353,7 +353,7 @@ const struct gl_video_opts gl_video_opts_hq_def = {
.dither_size = 6,
.temporal_dither_period = 1,
.fbo_format = GL_RGBA16,
- .fancy_downscaling = 1,
+ .correct_downscaling = 1,
.sigmoid_center = 0.75,
.sigmoid_slope = 6.5,
.sigmoid_upscaling = 1,
@@ -406,7 +406,7 @@ const struct m_sub_options gl_video_conf = {
SCALER_OPTS("tscale", 3),
OPT_FLAG("scaler-resizes-only", scaler_resizes_only, 0),
OPT_FLAG("linear-scaling", linear_scaling, 0),
- OPT_FLAG("fancy-downscaling", fancy_downscaling, 0),
+ OPT_FLAG("correct-downscaling", correct_downscaling, 0),
OPT_FLAG("sigmoid-upscaling", sigmoid_upscaling, 0),
OPT_FLOATRANGE("sigmoid-center", sigmoid_center, 0, 0.0, 1.0),
OPT_FLOATRANGE("sigmoid-slope", sigmoid_slope, 0, 1.0, 20.0),
@@ -478,6 +478,7 @@ const struct m_sub_options gl_video_conf = {
OPT_REPLACED("smoothmotion", "interpolation"),
OPT_REPLACED("smoothmotion-threshold", "tscale-param1"),
OPT_REPLACED("scale-down", "dscale"),
+ OPT_REPLACED("fancy-downscaling", "correct-downscaling"),
{0}
},
@@ -1592,17 +1593,15 @@ static void pass_scale_main(struct gl_video *p)
scaler = &p->scaler[1];
}
// When requesting fancy-downscaling and the clip is anamorphic, and because
// only a single fancy scale factor is used for both axes, enable fancy only
// when both axes are downscaled, and use the milder of the factors to not
// end up with too much blur on one axis (even if we end up with sub-optimal
// fancy factor on the other axis).
// This is better than not respecting fancy at all for anamorphic clips.
double f = MPMAX(xy[0], xy[1]);
- if (p->opts.fancy_downscaling && f < 1.0)
- {
+ if (p->opts.correct_downscaling && f < 1.0)
scale_factor = 1.0 / f;
- }
// Pre-conversion, like linear light/sigmoidization
GLSLF("// scaler pre-conversion\n");
@@ -1592,17 +1593,15 @@ static void pass_scale_main(struct gl_video *p)
scaler = &p->scaler[1];
}
- // When requesting fancy-downscaling and the clip is anamorphic, and because
- // only a single fancy scale factor is used for both axes, enable fancy only
+ // When requesting correct-downscaling and the clip is anamorphic, and
+ // because only a single scale factor is used for both axes, enable it only
// when both axes are downscaled, and use the milder of the factors to not
// end up with too much blur on one axis (even if we end up with sub-optimal
@@ -1592,17 +1593,15 @@ static void pass_scale_main(struct gl_video *p)
// when both axes are downscaled, and use the milder of the factors to not
// end up with too much blur on one axis (even if we end up with sub-optimal
- // fancy factor on the other axis).
- // This is better than not respecting fancy at all for anamorphic clips.
+ // scale factor on the other axis). This is better than not respecting
+ // correct scaling at all for anamorphic clips.
double f = MPMAX(xy[0], xy[1]);